package com.teamchat.client.sdk.demo;

import com.teamchat.client.annotations.OnKeyword;
import com.teamchat.client.sdk.ReceiveMessageErrorHandler;
import com.teamchat.client.sdk.SendMessageErrorHandler;
import com.teamchat.client.sdk.TeamchatAPI;
import com.teamchat.client.sdk.chatlets.TextChatlet;
import com.teamchat.client.sdk.impl.ReceiveMessageErrorContext;
import com.teamchat.client.sdk.impl.SendMessageErrorContext;

/**
 * A simple bot that response to the word "hi" that is posted in any room
 * containing the bot. The below code Demonstrates how set error handlers.
 * 
 * Please remember to update the authkey
 *
 */
public class ErrorHandlingDemo {
	public static final String authKey = "samplekey";
	public static final String userEmail = "user@example.com";

	/**
	 * This method creates instance of teamchat client, login using specified
	 * email/password and wait for messages from other users
	 **/
	public static void main(String[] args) {
		TeamchatAPI api = TeamchatAPI.fromFile("config.json")
				.setAuthenticationKey(authKey)
				.addReceiveMessageErrorHandler(new ReceiveMessageError())
				.addSendMessageErrorHandler(new SendMessageError());
		
		api.perform(api.context().create().add(userEmail)
				.post(new TextChatlet("hi")));
		api.startReceivingEvents(new HelloWorldBot());
	}

	/**
	 * This method posts Hello World message, when any user posts hi message to
	 * the logged in user (see main method)
	 **/
	@OnKeyword(value = "hi", description = "Test", isPublic = false)
	public void HelloWorld(TeamchatAPI api) {
		api.perform(api.context().currentRoom()
				.post(new TextChatlet("Hello World")));
	}

	static class SendMessageError implements SendMessageErrorHandler {

		@Override
		public void handleError(SendMessageErrorContext errorContext) {
			System.out.println("Inside SendMessageError");
			System.out.println("Recieved Error Message : "
					+ errorContext.getException().getMessage());

		}

	}

	static class ReceiveMessageError implements ReceiveMessageErrorHandler {

		@Override
		public void handleError(ReceiveMessageErrorContext errorContext) {
			System.out.println("Inside ReceiveMessageError");
			System.out.println("Recieved Error Message : "
					+ errorContext.getException().getMessage());
		}

	}
}
