package com.teamchat.client.sdk.demo;

import com.teamchat.client.sdk.TeamchatAPI;
import com.teamchat.client.sdk.chatlets.RichmediaChatlet;
import com.teamchat.client.sdk.impl.TeamchatAPIImpl;

/*
 * Posts an Richmedia (image) in a room. 
 * 
 * For posting image, two URLs are required, one for thumb nail and other the actual image.
 * 
 * Please remember to update the 3 parameter viz.
 * authkey, destUser.
 */
public class PostRichMediaChatletDemo {

	public static final String authKey = "samplekey";
	public static final String destUser = "Receivers email";
	public static final String filePath = "Sample File Path";
	public static final String httpUrl = "Sample Http URL";
	public static final String base64StringImage = "Sample base64 image String";
	public static final String fileName="SampleFileName";		
	public static void main(String[] args) {
		TeamchatAPI api = TeamchatAPIImpl.fromFile("config.json").setAuthenticationKey(authKey);
		api.perform(api
				.context()
				.create()
				.add(destUser)
				.post(new RichmediaChatlet()
						.setFileUrl(
								"https://farm4.staticflickr.com/3668/10815631375_1d49b50a13_z_d.jpg")
						.setFileSize("11 kb")
						.setFileMime("image/jpg")
						.setThumbnailUrl(
								"https://farm4.staticflickr.com/3668/10815631375_1d49b50a13_q_d.jpg")));

		postRichMediaChatletWithUpload(api);
	}

	/**
	 * This method uploads the required resource and then posts the rich media
	 * chatlet.
	 * @param api
	 */
	public static void postRichMediaChatletWithUpload(TeamchatAPI api){
		//Posting a file
		api.perform(api
				.context()
				.create()
				.add(destUser)
				.post(new RichmediaChatlet().upload(filePath, RichmediaChatlet.UploadType.FILE_PATH,fileName)));
		//Posting by http url
		api.perform(api
				.context()
				.create()
				.add(destUser)
				.post(new RichmediaChatlet().upload(httpUrl, RichmediaChatlet.UploadType.HTTP_URL,fileName)));
		//Posting base64 image String
		api.perform(api
				.context()
				.create()
				.add(destUser)
				.post(new RichmediaChatlet().upload(base64StringImage, RichmediaChatlet.UploadType.BASE64String,fileName)));
	}
}
