package com.teamchat.client.sdk.demo;

import com.teamchat.client.annotations.OnAlias;
import com.teamchat.client.annotations.OnKeyword;
import com.teamchat.client.sdk.TeamchatAPI;
import com.teamchat.client.sdk.chatlets.PrimaryChatlet;
/** 
 * Please remember to update the authkey
 */ 
public class SetReplyAndAddReplyActionDemo {

	public static final String authKey = "samplekey";

	/**
	 * This method creates instance of teamchat client, login using specified
	 * email/password and wait for messages from other users
	 **/
	public static void main(String[] args) {
		TeamchatAPI api = TeamchatAPI.fromFile("config.json")
				.setAuthenticationKey(authKey);

		api.startReceivingEvents(new SetReplyAndAddReplyActionDemo());
	}

	/**
	 * This method posts Primary Chatlet using setReplyAction, when any user posts setReply message to
	 * the logged in user (see main method).
	 * You can set only one replyaction useing set setReplyAction.
	 **/
	@OnKeyword("setReply")
	public void setReply(TeamchatAPI api) {
		api.perform(api
				.context()
				.currentRoom()
				.post(new PrimaryChatlet()
						.setQuestion("Test Set Reply")
						.setReplyAction("Send Hi", "resp",
								"Hi Using Set Reply Action").alias("getResp")));
	}
	
	/**
	 * This method posts Primary Chatlet using addReply Action, when any user posts addReply message to
	 * the logged in user (see main method)
	 * You can set multiple replyaction useing set addReplyAction.
	 **/
	@OnKeyword("addReply")
	public void addReply(TeamchatAPI api) {
		api.perform(api
				.context()
				.currentRoom()
				.post(new PrimaryChatlet()
						.setQuestion("Test Add Reply")
						.addReplyAction("Send Hi", "resp",
								"Hi Using Add Reply Action")
						.addReplyAction("Send Hello", "resp",
								"Hello Using Add Reply Action").alias("getResp")));
	}
	@OnAlias("getResp")
	public void response(TeamchatAPI api){
		System.out.println("Got Response : "+ api.context().currentReply().getField("resp"));
	}
}
